@@ -4,15 +4,26 @@ from typing import Collection, Iterable, List, Mapping, MutableMapping, Optional
 from typing import Any, Callable, MutableSequence, Generator
 
 from tabulate import tabulate
-import tinytim as tim
 
 import tinytable.column as column
 from tinytable.group import Group
 import tinytable.row as row
-from tinytable.csv import read_csv_file
+from tinytable.csv import data_to_csv_file, read_csv_file
 from tinytable.excel import read_excel_file
 from tinytable.sqlite import read_sqlite_table
 from tinytable.filter import Filter
+from tinytable.functional.edit import edit_column, drop_column_inplace, drop_column, drop_row_inplace
+from tinytable.functional.edit import edit_row_items_inplace, edit_row_values_inplace, drop_row
+from tinytable.functional.edit import drop_label_inplace, edit_row_items, edit_value_inplace
+from tinytable.functional.edit import drop_label, edit_value, edit_row_values
+from tinytable.functional.features import row_count, shape, size, column_names, index, values
+from tinytable.functional.features import column_values, head, tail
+from tinytable.functional.utils import slice_to_range, all_bool, nunique
+from tinytable.functional.filter import indexes_from_filter, only_columns, filter_list_by_indexes
+from tinytable.functional.filter import filter_by_indexes, sample_indexes
+from tinytable.functional.rows import row_dict, itertuples
+from tinytable.functional.copy import deepcopy_table, copy_table
+from tinytable.functional.group import groupby, sum_data, count_data
 
 
 class Table:
@@ -33,12 +44,12 @@ class Table:
     def _store_column(self, column_name: str, values: Iterable, inplace=True) -> Union[None, Table]:
         values = list(values)
         if inplace:
-            tim.edit.edit_column(self.data, column_name, values)
+            edit_column(self.data, column_name, values)
         else:
-            return Table(tim.edit.edit_column(self.data, column_name, values))
+            return Table(edit_column(self.data, column_name, values))
         
     def __len__(self) -> int:
-        return tim.features.row_count(self.data)
+        return row_count(self.data)
         
     def __repr__(self) -> str:
         index = True if self.labels is None else self.labels
@@ -69,9 +80,9 @@ class Table:
         # tbl[1:4] -> Table
         if isinstance(key, slice):
             validate_int_slice(key)
-            return self.filter_by_indexes(list(tim.utils.slice_to_range(key, len(self))))
+            return self.filter_by_indexes(list(slice_to_range(key, len(self))))
         if isinstance(key, list):
-            if tim.utils.all_bool(key):
+            if all_bool(key):
                 # tbl[[True, False, True, True]] -> Table
                 return self.filter(key)
             # tbl[['id', 'name']] -> Table
@@ -111,16 +122,16 @@ class Table:
 
     @property
     def shape(self) -> tuple[int, int]:
-        return tim.features.shape(self.data)
+        return shape(self.data)
 
     @property
     def size(self) -> int:
-        return tim.features.size(self.data)
+        return size(self.data)
 
     @property
     def columns(self) -> tuple[str]:
         """Column names."""
-        return tim.features.column_names(self.data)
+        return column_names(self.data)
 
     @columns.setter
     def columns(self, values: MutableSequence) -> None:
@@ -129,19 +140,19 @@ class Table:
 
     @property
     def index(self) -> column.Column:
-        return column.Column(tim.features.index(self.data), None, self, self.labels)
+        return column.Column(index(self.data), None, self, self.labels)
 
     @property
     def values(self) -> tuple[tuple]:
-        return tim.rows.values(self.data)
+        return values(self.data)
 
     def filter(self, f: Filter) -> Table:
-        indexes = tim.filter.indexes_from_filter(f)
+        indexes = indexes_from_filter(f)
         return self.filter_by_indexes(indexes)
 
     def only_columns(self, column_names: MutableSequence[str]) -> Table:
         """Return new Table with only column_names Columns."""
-        d = tim.filter.only_columns(self.data, column_names)
+        d = only_columns(self.data, column_names)
         return Table(d, self.labels)
 
     def _convert_index(self, index: int) -> int:
@@ -172,23 +183,23 @@ class Table:
    
     def row(self, index: int) -> row.Row:
         label = self._get_label(index)
-        return row.Row(tim.rows.row_dict(self.data, index), index, self, label)
+        return row.Row(row_dict(self.data, index), index, self, label)
 
     def column(self, column_name: str) -> column.Column:
-        return column.Column(tim.features.column_values(self.data, column_name), column_name, self, self.labels)
+        return column.Column(column_values(self.data, column_name), column_name, self, self.labels)
 
     def drop_column(self, column_name: str, inplace=True) -> Union[None, Table]:
         if inplace:
-            tim.edit.drop_column_inplace(self.data, column_name)
+            drop_column_inplace(self.data, column_name)
         else:
-            return Table(tim.edit.drop_column(self.data, column_name), self.labels)
+            return Table(drop_column(self.data, column_name), self.labels)
 
     def drop_row(self, index: int, inplace=True) -> Union[None, Table]:
         if inplace:
-            tim.edit.drop_row_inplace(self.data, index)
-            tim.edit.drop_label_inplace(self.labels, index)
+            drop_row_inplace(self.data, index)
+            drop_label_inplace(self.labels, index)
         else:
-            return Table(tim.edit.drop_row(self.data, index), tim.edit.drop_label(self.labels, index))
+            return Table(drop_row(self.data, index), drop_label(self.labels, index))
 
     def keys(self) -> tuple[str]:
         return self.columns
@@ -203,19 +214,19 @@ class Table:
         return column.iteritems(self.data, self)
 
     def itertuples(self) -> Generator[tuple, None, None]:
-        return tim.rows.itertuples(self.data)
+        return itertuples(self.data)
     
     def edit_row(self, index: int, values: Union[Mapping, MutableSequence], inplace=True) -> Union[None, Table]:
         if inplace:
             if isinstance(values, Mapping):
-                tim.edit.edit_row_items_inplace(self.data, index, values)
+                edit_row_items_inplace(self.data, index, values)
             elif isinstance(values, MutableSequence):
-                tim.edit.edit_row_values_inplace(self.data, index, values)
+                edit_row_values_inplace(self.data, index, values)
         else:
             if isinstance(values, Mapping):
-                data = tim.edit.edit_row_items(self.data, index, values)
+                data = edit_row_items(self.data, index, values)
             elif isinstance(values, MutableSequence):
-                data = tim.edit.edit_row_values(self.data, index, values)
+                data = edit_row_values(self.data, index, values)
             return Table(data, copy.copy(self.labels))
             
     def edit_column(self, column_name: str, values: MutableSequence, inplace=True) ->Union[None, Table]:
@@ -223,14 +234,14 @@ class Table:
 
     def edit_value(self, column_name: str, index: int, value: Any, inplace=True) -> Union[None, Table]:
         if inplace:
-            tim.edit.edit_value_inplace(self.data, column_name, index, value)
+            edit_value_inplace(self.data, column_name, index, value)
         else:
-            return Table(tim.edit.edit_value(self.data, column_name, index, value), copy.copy(self.labels))
+            return Table(edit_value(self.data, column_name, index, value), copy.copy(self.labels))
 
     def copy(self, deep=False) -> Table:
         if deep:
-             return Table(tim.copy.deepcopy_table(self.data), copy.deepcopy(self.labels))
-        return Table(tim.copy.copy_table(self.data), copy.copy(self.labels))
+             return Table(deepcopy_table(self.data), copy.deepcopy(self.labels))
+        return Table(copy_table(self.data), copy.copy(self.labels))
 
     def cast_column_as(self, column_name: str, data_type: Callable) -> None:
         self.data[column_name] = [data_type(value) for value in self.data[column_name]]
@@ -245,7 +256,7 @@ class Table:
 
     def to_csv(self, path: str) -> None:
         """Save Table as csv at path."""
-        ...
+        data_to_csv_file(self.data, path)
 
     def to_excel(self, path: str) -> None:
         """Save Table in Excel Workbook."""
@@ -262,36 +273,36 @@ class Table:
         return None if self.labels is None else self.labels[5:]
 
     def head(self, n: int = 5) -> Table:
-        return Table(tim.features.head(self.data, n), self.label_head(n))
+        return Table(head(self.data, n), self.label_head(n))
 
     def tail(self, n: int = 5) -> Table:
-        return Table(tim.features.tail(self.data, n), self.label_tail(n))
+        return Table(tail(self.data, n), self.label_tail(n))
 
     def nunique(self) -> dict[str, int]:
         """Count number of distinct values in each column.
            Return dict with number of distinct values.
         """
-        return tim.utils.nunique(self.data)
+        return nunique(self.data)
 
     def filter_by_indexes(self, indexes: MutableSequence[int]) -> Table:
         """return only rows in indexes"""
-        labels = None if self.labels is None else tim.filter.filter_list_by_indexes(self.labels, indexes)
-        return Table(tim.filter.filter_by_indexes(self.data, indexes), labels=labels)
+        labels = None if self.labels is None else filter_list_by_indexes(self.labels, indexes)
+        return Table(filter_by_indexes(self.data, indexes), labels=labels)
 
     def sample(self, n, random_state=None) -> Table:
         """return random sample of rows"""
-        indexes = tim.filter.sample_indexes(self.data, n, random_state)
-        labels = None if self.labels is None else tim.filter.filter_list_by_indexes(self.labels, indexes)
-        return Table(tim.filter.filter_by_indexes(self.data, indexes), labels=labels)
+        indexes = sample_indexes(self.data, n, random_state)
+        labels = None if self.labels is None else filter_list_by_indexes(self.labels, indexes)
+        return Table(filter_by_indexes(self.data, indexes), labels=labels)
 
     def groupby(self, by: Union[str, Collection]) -> Group:
-        return Group([(value, Table(data)) for value, data in tim.group.groupby(self.data, by)], by)
+        return Group([(value, Table(data)) for value, data in groupby(self.data, by)], by)
 
     def sum(self) -> dict:
-        return tim.group.sum_data(self.data)
+        return sum_data(self.data)
 
     def count(self) -> dict:
-        return tim.group.count_data(self.data)
+        return count_data(self.data)
 
 
 def read_csv(path: str):
